import bb.cascades 1.0

Page
{
    property bool addContactsOnTap: true
    property bool allowCallsOverMobile: true
    property bool autoRecordVoiceNotes: false
    property bool saveChatHistory: false
    property bool receiveCalls: true
    property bool showAvatarsOnBubbles: true
    property bool showCountryTime: false
    property bool showListeningTo: false
    property bool showAppUpdates: true
    property bool showMusicUpdates: true
    property bool showSecurityQuestion: false
    property bool showVideoChatCamera: true
    property bool enableTestMode: false
    property bool showVideoChatSettings: false
    property string layoutGridMode: "grid"
    property bool enableClearChatHistory: true
    property bool enableMobileCalls: false
    property bool editInstantReplyListSettingVisible: false
    property string visualStyle: ""
    
    titleBar: TitleBar {
        title: qsTr("BBM Settings") + Retranslate.onLanguageChanged
    }

    content: ScrollView 
    {
            Container // main container
            {
                layout: StackLayout {
                    orientation: LayoutOrientation.TopToBottom
                }
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill

				Header {
                    title: qsTr("Status") + Retranslate.onLanguageChanged
        		}
				
				Container {
				
				leftPadding: _UILayoutManager.defaultPadding
                rightPadding: _UILayoutManager.defaultPadding
                topPadding: _UILayoutManager.defaultPadding   
                bottomPadding: _UILayoutManager.defaultPadding
				
                SettingPairToggle
                {
                    objectName: "showListeningTo"
                    toggleButtonInstance.objectName: "showListeningToToggleBtn"
                    enableMode: showListeningTo
                    labelText: qsTr("Show What I'm Listening To") + Retranslate.onLanguageChanged
                }
                
                SettingPairToggle
                {
                    
                    objectName: "musicUpdateToggle"
                    toggleButtonInstance.objectName: "musicUpdateToggleBtn"
                    enableMode: showMusicUpdates
                    labelText: qsTr("Music Status Updates") + Retranslate.onLanguageChanged
                }
                
                SettingPairToggle
                {
                    objectName: "showLocationTimezoneToggle"
                    toggleButtonInstance.objectName: "showLocationTimezoneToggleBtn"
                    enableMode: showCountryTime
                    labelText: qsTr("Show My Country and Time") + Retranslate.onLanguageChanged
                }
            }
                
                Header {
                    title: qsTr("Chats") + Retranslate.onLanguageChanged
                }
                
                Container {
                    
                    leftPadding: _UILayoutManager.defaultPadding
                    rightPadding: _UILayoutManager.defaultPadding
                    topPadding: _UILayoutManager.defaultPadding   
                    bottomPadding: _UILayoutManager.defaultPadding
                
                SettingPairToggle
                {
                    objectName: "chatBubbleHeadersToggle"
                    toggleButtonInstance.objectName: "chatBubbleHeadersToggleBtn"
                    enableMode: showAvatarsOnBubbles
                    labelText: qsTr("Show Display Pictures in Chats") + Retranslate.onLanguageChanged
                }
                
                SettingPairToggle
                {
                    objectName: "saveChatHistoryToggle"
                    toggleButtonInstance.objectName: "saveChatHistoryToggleButton"
                    enableMode: saveChatHistory
                    labelText: qsTr("Save Chat History") + Retranslate.onLanguageChanged
                }
                
                Button
                {
                    horizontalAlignment: HorizontalAlignment.Fill
                    objectName: "clearChatHistoryButton"
                    text: qsTr("Delete Chat History") + Retranslate.onLanguageChanged
                }
            }
                
                Header {
                    title: qsTr("Contacts") + Retranslate.onLanguageChanged
                }
                
                Container {
                    
                    leftPadding: _UILayoutManager.defaultPadding
                    rightPadding: _UILayoutManager.defaultPadding
                    topPadding: _UILayoutManager.defaultPadding   
                    bottomPadding: _UILayoutManager.defaultPadding
                
                    DropDown {
                        objectName: "contactLayout"
                        title: qsTr("Contacts Layout") + Retranslate.onLanguageChanged
                        Option {
                            text: qsTr("Grid") + Retranslate.onLanguageChanged
                            value: "grid"
                            selected: value == layoutGridMode
                        }
                        Option {
                            text: qsTr("List") + Retranslate.onLanguageChanged
                            value: "list"
                            selected: value == layoutGridMode
                        }
                    }
                
                SettingPairToggle
                {
                    objectName: "nfcToggle"
                    toggleButtonInstance.objectName: "nfcToggleBtn"
                    enableMode: addContactsOnTap
                    labelText: qsTr("Add Contacts On Tap") + Retranslate.onLanguageChanged
                    visible: nfcManager.nfcEnabled
                }
            }
                
                Header {
                    title: qsTr("Miscellaneous") + Retranslate.onLanguageChanged
                }
                
                Container {
                    
                    leftPadding: _UILayoutManager.defaultPadding
                    rightPadding: _UILayoutManager.defaultPadding
                    topPadding: _UILayoutManager.defaultPadding   
                    bottomPadding: _UILayoutManager.defaultPadding
                    
                    SettingPairToggle
                    {
                        visible: showVideoChatSettings
                        objectName: "allowMobileCalls"
                        toggleButtonInstance.objectName: "allowMobileCallsToggleBtn"
                        enableMode: allowCallsOverMobile
                        labelText: qsTr("Allow BBM Calls Over Mobile Networks") + Retranslate.onLanguageChanged
                        enabled: enableMobileCalls
                    }
                    
                    SettingPairToggle
                    {
                        objectName: "autoRecordVoiceNotes"
                        toggleButtonInstance.objectName: "autoRecordVoiceNotesBtn"
                        enableMode: autoRecordVoiceNotes
                        labelText: qsTr("Automatically Record Voice Notes") + Retranslate.onLanguageChanged
                    }
                    
                    DropDown {
                        objectName: "visualStyleDropDown"
                        title: qsTr("Visual Theme") + Retranslate.onLanguageChanged
                        Option {
                            text: qsTr("Light") + Retranslate.onLanguageChanged
                            value: "Bright"
                            selected: value == visualStyle
                        }
                        Option {
                            text: qsTr("Dark") + Retranslate.onLanguageChanged
                            value: "Dark"
                            selected: value == visualStyle
                        }
                    }
                    
                    Label {
                        text: qsTr("Changes to the visual theme will take place when BBM is relaunched.") + Retranslate.onLanguageChanged
                        multiline: true
                    }
                    
                    SettingPairToggle
                    {
                        objectName: "showSecurityQuestion"
                        toggleButtonInstance.objectName: "showSecurityQuestionToggleBtn"
                        enableMode: showSecurityQuestion
                        labelText: qsTr("Security Question on Invites") + Retranslate.onLanguageChanged
                    }

                Button
                {
                    horizontalAlignment: HorizontalAlignment.Fill
                    objectName: "blockedContactListButton"
                    text: qsTr("Blocked Contacts") + Retranslate.onLanguageChanged
                    bottomMargin: _UILayoutManager.defaultPadding
                }
                
                
            }
                
                /*
                SettingPairToggle
                {
                    objectName: "appUpdateToggle"
                    toggleButtonInstance.objectName: "appUpdateToggleBtn"
                    enableMode: showAppUpdates
                    labelText: qsTr("App Status Updates") + Retranslate.onLanguageChanged
                }
                */
                
            } // end main container
        }
}
